@@ -1,6 +1,6 @@
 //AD  <- These first 4 characters need to be the first 4 characters to identify the ECMAScript file to Avidemux
 var app = new Avidemux();
-var file="/work/samples/2mn.avi";
+var file="/work/samples/avi/2mn.avi";
 var goodfcc="DIV3";
 var fps;
 /* Load file
@@ -8,7 +8,7 @@ var fps;
 app.load(file);
 /* Test get fps 
 */
-fps=app.video.getFCC();
+fps=app.video.fcc;
 //app.displayInfo("FPS "+fps);
 if(fps==goodfcc)
 {
@@ -18,6 +18,6 @@ else
 	app.displayError("Good:"+goodfcc+"Bad:"+fps);
 	app.displayError("Wrong fcc ");
 }
-
+print("All ok");
 /* End of test
 */
