@@ -1,6 +1,6 @@
 //AD  <- These first 4 characters need to be the first 4 characters to identify the ECMAScript file to Avidemux
 var app = new Avidemux();
-var file="/work/samples/2mn.avi";
+var file="/work/samples/avi/2mn.avi";
 var goodwidth=512;
 var goodheight=384;
 var fps;
@@ -9,7 +9,7 @@ var fps;
 app.load(file);
 /* Test get fps 
 */
-fps=app.video.getWidth();
+fps=app.video.width;
 //app.displayInfo("FPS "+fps);
 if(fps==goodwidth)
 {
@@ -18,7 +18,7 @@ else
 {
 	app.displayError("Wrong width "+fps+"expected "+goodwidth);
 }
-fps=app.video.getHeight();
+fps=app.video.height;
 //app.displayInfo("FPS "+fps);
 if(fps==goodheight)
 {
@@ -28,6 +28,6 @@ else
 	app.displayError("Wrong height "+fps+"expected "+goodheight);
 }
 
-
+print("all ok");
 /* End of test
 */
