@@ -13,8 +13,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef __ADM_encoder_copy__
-#define __ADM_encoder_copy__
+#ifndef __ADM_encoder_requant__
+#define __ADM_encoder_requant__
 
 
 class EncoderRequant:public Encoder
@@ -31,7 +31,7 @@ public:
           ~EncoderRequant ();		// can be called twice if needed ..
   virtual int getRequirements (void);
   virtual uint8_t isDualPass (void);
-  virtual uint8_t configure (AVDMGenericVideoStream * instream);
+  virtual uint8_t configure (AVDMGenericVideoStream * instream, int useExistingLogFile);
   virtual uint8_t encode (uint32_t frame, ADMBitstream *out);
   virtual uint8_t setLogFile (const char *p, uint32_t fr);
   virtual uint8_t stop (void);
