@@ -85,13 +85,27 @@ uint32_t flvHeader::read32(void)
     \fn     readFlvString
     \brief  read pascal like string
 */
+#define FLV_MAX_STRING 255
 char *flvHeader::readFlvString(void)
 {
-static char stringz[255];
+static uint8_t stringz[FLV_MAX_STRING+1];
     int size=read16();
-    read(size,(uint8_t *)stringz);
+    if(size>FLV_MAX_STRING)
+    {
+        int pre=FLV_MAX_STRING;
+        read(pre,stringz);
+        printf("String way too large :%d\n",size);
+        mixDump(stringz,pre);
+        stringz[0]='X';
+        stringz[1]='X';
+        stringz[2]=0;
+        stringz[FLV_MAX_STRING]=0;
+        Skip(size-FLV_MAX_STRING);
+        return (char *)stringz;
+    }
+    read(size,stringz);
     stringz[size]=0;
-    return stringz;
+    return (char *)stringz;
 }
 
 extern "C" {
@@ -129,7 +143,9 @@ bool flvHeader::parseOneMeta(const char *s,uint64_t endPos)
             printf("type :%d : ",type);
             switch(type)
             {
-                case AMF_DATA_TYPE_OBJECT_END:break;
+                case AMF_DATA_TYPE_OBJECT_END:
+                                fseek(_fd,endPos,SEEK_SET);
+                                break;
                 case AMF_DATA_TYPE_OBJECT: 
                 {
                         printf("\n");
@@ -210,27 +226,22 @@ xxer:
 uint8_t flvHeader::parseMetaData(uint32_t remaining)
 {
     uint32_t endPos=ftello(_fd)+remaining;
+    // Check the first one is onMetaData...
+    uint8_t type=read8();
+    char *z;
+    if(type!=AMF_DATA_TYPE_STRING) // String!
+        goto endit;
+    z=readFlvString();
+    printf("[FlashString] %s\n",z);
+    if(z && strncmp(z,"onMetaData",10)) goto endit;
+    // Normally the next one is mixed array
+    while(ftello(_fd)<endPos-4)
     {
-        // Check the first one is onMetaData...
-        uint8_t type=read8();
-        if(type!=AMF_DATA_TYPE_STRING) // String!
-            goto endit;
-        char *z=readFlvString();
-        printf("[FlashString] %s\n",z);
-        if(z && strncmp(z,"onMetaData",10)) goto endit;
-        // Normally the next one is mixed array
-        Skip(4);
-        Skip(1);
-        while(ftello(_fd)<endPos-4)
-        {
-            char *s=readFlvString();
-            printf("[FlvType]  String : %s",s);
-            
-            if(false==parseOneMeta(s,endPos)) goto endit;
-        }
+         if(false==parseOneMeta("meta",endPos)) goto endit;
     }
 endit:
     fseeko(_fd,endPos,SEEK_SET);
+    updateDimensionWithMeta(videoCodec);
     return 1;
 }
 /**
@@ -348,6 +359,7 @@ uint8_t flvHeader::open(const char *name)
     size=read24();
     pts=read24();
     read32(); // ???
+    if(!size) continue;
     uint32_t remaining=size;
     //printf("[FLV] At %08x found type %x size %u pts%u\n",pos,type,size,pts);
     switch(type)
@@ -390,9 +402,9 @@ uint8_t flvHeader::open(const char *name)
             remaining--;
             int frameType=flags>>4;
             
-            int codec=(flags)&0xf;
+            videoCodec=(flags)&0xf;
             
-            if(codec==FLV_CODECID_VP6 || codec==FLV_CODECID_VP6A)
+            if(videoCodec==FLV_CODECID_VP6 || videoCodec==FLV_CODECID_VP6A)
             {
               read8(); // 1 byte of extraData
               remaining--;
@@ -400,10 +412,10 @@ uint8_t flvHeader::open(const char *name)
             }
             if(firstVideo==true) // first frame..
             {
-                if(!setVideoHeader(codec,&remaining)) return 0;
+                if(!setVideoHeader(videoCodec,&remaining)) return 0;
                 firstVideo=false;
             }
-            if(codec==FLV_CODECID_H264)
+            if(videoCodec==FLV_CODECID_H264)
             {
                 if(true==extraHeader(videoTrack,&remaining,true,&cts)) continue;
 
@@ -450,6 +462,27 @@ uint8_t flvHeader::open(const char *name)
   
   return 1;
 }
+bool flvHeader::updateDimensionWithMeta(uint32_t codec)
+{
+    if(codec==0xFFFF) return false;
+    printf("We got metadata : %d x %d\n",(int)metaWidth,(int)metaHeight,(int)codec);
+    if( metaWidth && metaHeight )
+    {
+        switch(codec)
+        {
+            case FLV_CODECID_VP6A:
+            case FLV_CODECID_H264:
+            case FLV_CODECID_VP6:
+
+                    _video_bih.biHeight=_mainaviheader.dwHeight=metaHeight ;
+                    _video_bih.biWidth=_mainaviheader.dwWidth=metaWidth;
+                    break;
+            default:break;
+        }
+    }
+    return true;
+}
+
 /**
       \fn setVideoHeader
       \brief Set codec and stuff
@@ -472,14 +505,10 @@ uint8_t flvHeader::setVideoHeader(uint8_t codec,uint32_t *remaining)
       default :                         _videostream.fccHandler=_video_bih.biCompression=fourCC::get((uint8_t *)"XXX");break;
       
     }
-     if( metaWidth && metaHeight )
-        if( codec==FLV_CODECID_VP6A  || codec==FLV_CODECID_H264 || codec==FLV_CODECID_VP6) 
-        {
-                _video_bih.biHeight=_mainaviheader.dwHeight=metaHeight ;
-                _video_bih.biWidth=_mainaviheader.dwWidth=metaWidth;
-        }
 
-    if(codec==FLV_CODECID_H263)
+    updateDimensionWithMeta(codec);
+
+    if(codec==FLV_CODECID_H263 && *remaining)
     {
       uint32_t len=*remaining,width,height;
       uint32_t pos=ftello(_fd);
@@ -644,7 +673,9 @@ uint8_t flvHeader::close(void)
 */
 
  flvHeader::flvHeader( void ) : vidHeader()
-{ 
+{
+    metaWidth=metaHeight=metaFps1000=0; 
+    videoCodec=0xFFFF;
     _fd=NULL;
     _filename=NULL;
     videoTrack=NULL;
