@@ -99,7 +99,7 @@ entryDesc entry;
       memset(&entry,0,sizeof(entry));
       /* Set some defaults value */
 
-      entry.chan=2;
+      entry.chan=1;
 
       entryWalk(  (ADM_ebml_file *)head,headlen,&entry);
       entry.dump();
@@ -179,7 +179,11 @@ entryDesc entry;
       {
          uint32_t  streamIndex;
          mkvTrak *t=&(_tracks[1+_nbAudioTrack]);
-
+         if(!entry.fq)
+         {
+            printf("Warning : Zero frequency! Replacing it by 48000 hz, that might be incorrect\n");
+            entry.fq=48000; 
+         }
          t->wavHeader.encoding=entry.fcc;
          t->wavHeader.channels=entry.chan;
          t->wavHeader.frequency=entry.fq;
