@@ -49,14 +49,14 @@ extern void filterListAll(void );
 extern uint8_t loadVideoCodecConf( const char *name);
 extern int A_saveBunchJpg(const char *name);
 extern void filterLoadXml(const char *n);
-extern int A_appendAvi (const char *name);
+extern int A_appendAvi (const char *name, bool silent = 0);
 extern void A_saveAudio(char *name);
 extern int A_loadNone( void );
 extern void A_saveAudioDecodedTest(char *name);
 extern uint8_t A_SaveAudioNVideo(char *name);
-extern int A_loadMP3(char *name);
-extern int A_loadAC3(char *name);
-extern int A_loadWave(char *name);
+extern int A_loadMP3(const char *name);
+extern int A_loadAC3(const char *name);
+extern int A_loadWave(const char *name);
 extern void GUI_Quiet( void);
 extern bool A_parseECMAScript(const char *name);
 extern void GUI_Verbose( void);
