@@ -14,7 +14,6 @@
 #include "config.h"
 #undef QT_TR_NOOP
 
-#include <QtCore/QUrl>
 #include <QtCore/QDir>
 #include <QtGui/QKeyEvent>
 #include <QtGui/QGraphicsView>
@@ -33,6 +32,7 @@
 #include "gtkgui.h"
 #include "DIA_coreToolkit.h"
 #include "ADM_userInterfaces/ADM_render/GUI_renderInternal.h"
+#include "ADM_audiofilter/audioeng_buildfilters.h"
 
 extern int global_argc;
 extern char **global_argv;
@@ -53,11 +53,12 @@ extern void initTranslator(void);
 extern void destroyTranslator(void);
 extern ADM_RENDER_TYPE UI_getPreferredRender(void);
 extern int A_openAvi(const char *name);
-extern int A_appendAvi(const char *name);
+extern int A_appendAvi(const char *name, bool silent);
 extern char *actual_workbench_file;
 extern void FileSel_ReadWrite(SELFILE_CB *cb, int rw, const char *name, const char *actual_workbench_file);
 extern bool A_parseECMAScript(const char *name);
 extern void saveCrashProject(void);
+extern bool loadAudio(const char *filename);
 
 int SliderIsShifted=0;
 static void setupMenus(void);
@@ -106,10 +107,17 @@ int UI_readCurTime(uint16_t &hh, uint16_t &mm, uint16_t &ss, uint16_t &ms);
 void UI_updateFrameCount(uint32_t curFrame);
 void UI_updateTimeCount(uint32_t curFrame,uint32_t fps);
 extern void UI_purge(void);
-/*
-    Declare the class that will be our main window
 
-*/
+class FileDropEvent : public QEvent
+{
+public:
+	QList<QUrl> files;
+
+	FileDropEvent(QList<QUrl> files) : QEvent(QEvent::User)
+	{
+		this->files = files;
+	}
+};
 
 void MainWindow::comboChanged(int z)
 {
@@ -235,6 +243,10 @@ MainWindow::MainWindow() : QMainWindow()
 	qtRegisterDialog(this);
 	ui.setupUi(this);
 
+#ifdef __WIN32
+	mswin.init(this->winId());
+#endif
+
 	this->setStatusBar(0);
 	this->adjustSize();
 
@@ -479,6 +491,9 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event)
 				thumbSlider->move(0, (ui.sliderPlaceHolder->height() - thumbSlider->height()) / 2);
 			}
 
+			break;
+		case QEvent::User:
+			this->openFiles(((FileDropEvent*)event)->files);
 			break;
 	}
 
@@ -498,30 +513,38 @@ void MainWindow::dragEnterEvent(QDragEnterEvent *event)
 
 void MainWindow::dropEvent(QDropEvent *event)
 {
-	QList<QUrl> urlList;
-	QString fileName;
-	QFileInfo info;
-
 	if (event->mimeData()->hasUrls())
 	{
-		urlList = event->mimeData()->urls();
+		QCoreApplication::postEvent(this, new FileDropEvent(event->mimeData()->urls()));
 
-		for (int fileIndex = 0; fileIndex < urlList.size(); fileIndex++)
+		event->acceptProposedAction();
+	}
+}
+
+void MainWindow::openFiles(QList<QUrl> urlList)
+{
+	QFileInfo info;
+
+	for (int fileIndex = 0; fileIndex < urlList.size(); fileIndex++)
+	{
+		QString fileName = urlList[fileIndex].toLocalFile();
+		QFileInfo info(fileName);
+
+		if (info.isFile())
 		{
-			fileName = urlList[fileIndex].toLocalFile();
-			info.setFile(fileName);
-
-			if (info.isFile())
+			if (avifileinfo)
 			{
-				if (avifileinfo)
-					FileSel_ReadWrite(reinterpret_cast <void (*)(const char *)> (A_appendAvi), 0, fileName.toUtf8().data(), actual_workbench_file);
-				else
-					FileSel_ReadWrite(reinterpret_cast <void (*)(const char *)> (A_openAvi), 0, fileName.toUtf8().data(), actual_workbench_file);
+				if (!A_appendAvi(fileName.toUtf8().constData(), 1))
+				{
+					loadAudio(fileName.toUtf8().constData());
+				}
+			}
+			else
+			{
+				FileSel_ReadWrite(reinterpret_cast <void (*)(const char *)> (A_openAvi), 0, fileName.toUtf8().data(), actual_workbench_file);
 			}
 		}
 	}
-
-	event->acceptProposedAction();
 }
 
 void MainWindow::previousIntraFrame(void)
@@ -673,6 +696,14 @@ MainWindow::~MainWindow()
 	clearCustomMenu();
 	renderDestroy();
 }
+
+#ifdef __WIN32
+bool MainWindow::winEvent(MSG *message, long *result)
+{
+    return mswin.winEvent(message, result);
+}
+#endif
+
 static const UI_FUNCTIONS_T UI_Hooks=
     {
         ADM_RENDER_API_VERSION_NUMBER,
