@@ -2,6 +2,7 @@
 #define Q_gui2_h
 
 #include <QtCore/QFileInfo>
+#include <QtCore/QUrl>
 #include <QtGui/QSlider>
 #include <QtGui/QWidget>
 #include <QtGui/QMenu>
@@ -10,6 +11,10 @@
 #include "T_thumbSlider.h"
 #include "ui_gui2.h"
 
+#ifdef __WIN32
+#include "Q_mswin.h"
+#endif
+
 class MainWindow : public QMainWindow
 {
 	Q_OBJECT
@@ -22,6 +27,11 @@ public:
 
 	Ui_MainWindow ui;
 
+#ifdef __WIN32
+	Q_mswin mswin;
+	bool winEvent(MSG *message, long *result);
+#endif
+
 public slots:
 	void timeChanged(int);
 	void buttonPressed(void);
@@ -53,5 +63,6 @@ protected:
 	void dropEvent(QDropEvent *event);
 	void closeEvent(QCloseEvent *event);
 	void addDirEntryToMenu(QMenu *parentMenu, QString path);
+	void openFiles(QList<QUrl>);
 };
 #endif	// Q_gui2_h
