@@ -94,6 +94,13 @@ x264ConfigDialog::x264ConfigDialog(vidEncConfigParameters *configParameters, vid
 	connect(ui.dct8x8CheckBox, SIGNAL(toggled(bool)), this, SLOT(dct8x8CheckBox_toggled(bool)));
 	connect(ui.p8x8CheckBox, SIGNAL(toggled(bool)), this, SLOT(p8x8CheckBox_toggled(bool)));
 
+#if X264_BUILD < 110
+	ui.weightedPPredictComboBox->clear();
+	ui.weightedPPredictComboBox->addItem(tr("Disabled"));
+	ui.weightedPPredictComboBox->addItem(tr("Blind Offset"));
+	ui.weightedPPredictComboBox->addItem(tr("Smart Analysis"));
+#endif
+
 	// Frame tab
 	connect(ui.loopFilterCheckBox, SIGNAL(toggled(bool)), this, SLOT(loopFilterCheckBox_toggled(bool)));
 
@@ -343,7 +350,8 @@ void x264ConfigDialog::saveAsButton_pressed(void)
 		delete [] xml;
 
 		fillConfigurationComboBox();
-		selectConfiguration(&QFileInfo(configFileName).completeBaseName(), PLUGIN_CONFIG_USER);
+		QString qs=QFileInfo(configFileName).completeBaseName();
+		selectConfiguration(&qs, PLUGIN_CONFIG_USER);
 	}
 
 	delete [] configDirectory;
@@ -579,8 +587,8 @@ bool x264ConfigDialog::loadPresetSettings(vidEncOptions *encodeOptions, x264Opti
 
 	disableGenericSlots = true;
 	options->getPresetConfiguration(&configurationName, &configurationType);
-
-	bool foundConfig = selectConfiguration(&QString(configurationName), configurationType);
+	QString qs=QString(configurationName);
+	bool foundConfig = selectConfiguration(&qs, configurationType);
 
 	if (!foundConfig)
 		printf("Configuration %s (type %d) could not be found.  Using snapshot.\n", configurationName, configurationType);
@@ -778,6 +786,7 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 	ui.fastPSkipCheckBox->setChecked(options->getFastPSkip());
 	ui.dctDecimateCheckBox->setChecked(options->getDctDecimate());
 	ui.psychoRdoSpinBox->setValue(options->getPsychoRdo());
+	ui.psychoTrellisSpinBox->setValue(options->getPsychoTrellis());
 
 	ui.noiseReductionSpinBox->setValue(options->getNoiseReduction());
 	ui.interLumaSpinBox->setValue(options->getInterLumaDeadzone());
@@ -814,8 +823,9 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 	ui.quantiserCurveCompressSpinBox->setValue((int)floor(options->getQuantiserCurveCompression() * 100 + .5));
 	ui.quantiserBeforeCompressSpinBox->setValue(options->getReduceFluxBeforeCurveCompression());
 	ui.quantiserAfterCompressSpinBox->setValue(options->getReduceFluxAfterCurveCompression());
-	ui.aqVarianceCheckBox->setChecked(options->getAdaptiveQuantiserMode() == X264_AQ_VARIANCE);
+	ui.aqVarianceCheckBox->setChecked(options->getAdaptiveQuantiserMode() > X264_AQ_NONE);
 	ui.aqStrengthSpinBox->setValue(options->getAdaptiveQuantiserStrength());
+	ui.aqAlgoComboBox->setCurrentIndex(options->getAdaptiveQuantiserMode() == X264_AQ_AUTOVARIANCE);
 
 	// Advanced tab
 	ui.vbvMaxBitrateSpinBox->setValue(options->getVbvMaximumBitrate());
@@ -1010,6 +1020,7 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 	options->setFastPSkip(ui.fastPSkipCheckBox->isChecked());
 	options->setDctDecimate(ui.dctDecimateCheckBox->isChecked());
 	options->setPsychoRdo(ui.psychoRdoSpinBox->value());
+	options->setPsychoTrellis(ui.psychoTrellisSpinBox->value());
 	options->setNoiseReduction(ui.noiseReductionSpinBox->value());
 	options->setInterLumaDeadzone(ui.interLumaSpinBox->value());
 	options->setIntraLumaDeadzone(ui.intraLumaSpinBox->value());
@@ -1043,7 +1054,7 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 	options->setReduceFluxAfterCurveCompression(ui.quantiserAfterCompressSpinBox->value());
 
 	if (ui.aqVarianceCheckBox->isChecked())
-		options->setAdaptiveQuantiserMode(X264_AQ_VARIANCE);
+		options->setAdaptiveQuantiserMode((ui.aqAlgoComboBox->currentIndex() > 0) ? X264_AQ_AUTOVARIANCE : X264_AQ_VARIANCE);
 	else
 		options->setAdaptiveQuantiserMode(X264_AQ_NONE);
 
