@@ -420,13 +420,34 @@ void x264Options::setCabac(bool cabac)
 #if X264_BUILD > 101
 unsigned int x264Options::getOpenGopMode(void)
 {
+#if X264_BUILD > 114
+	if (_param.b_open_gop == 1)
+	{
+		if (_param.b_bluray_compat == 1)
+		{
+			return 2;
+		}
+		else
+		{
+			return 1;
+		}
+	}
+
+	return 0;
+#else
 	return _param.i_open_gop;
+#endif
 }
 
 void x264Options::setOpenGopMode(unsigned int openGopMode)
 {
+#if X264_BUILD > 114
+	_param.b_open_gop = (openGopMode > 0 ? 1 : 0);
+	_param.b_bluray_compat = (openGopMode == 2 ? 1 : 0);
+#else
 	if (openGopMode < 3)
 		_param.i_open_gop = openGopMode;
+#endif
 }
 #endif
 
@@ -715,7 +736,7 @@ unsigned int x264Options::getSubpixelRefinement(void)
 
 void x264Options::setSubpixelRefinement(unsigned int subpixelRefinement)
 {
-	if (subpixelRefinement >= 1 && subpixelRefinement <= 9)
+	if (subpixelRefinement >= 1 && subpixelRefinement <= 10)
 		_param.analyse.i_subpel_refine = subpixelRefinement;
 }
 
@@ -777,10 +798,21 @@ float x264Options::getPsychoRdo(void)
 
 void x264Options::setPsychoRdo(float psychoRdo)
 {
-	if (psychoRdo >= 0 && psychoRdo <= 10)
+	if (psychoRdo >= 0.0f && psychoRdo <= 10.0f)
 		_param.analyse.f_psy_rd = psychoRdo;
 }
 
+float x264Options::getPsychoTrellis(void)
+{
+	return _param.analyse.f_psy_trellis;
+}
+
+void x264Options::setPsychoTrellis(float psychoTrellis)
+{
+	if (psychoTrellis >= 0.0f && psychoTrellis <= 10.0f)
+		_param.analyse.f_psy_trellis = psychoTrellis;
+}
+
 unsigned int x264Options::getNoiseReduction(void)
 {
 	return _param.analyse.i_noise_reduction;
@@ -821,7 +853,7 @@ unsigned int x264Options::getQuantiserMinimum(void)
 
 void x264Options::setQuantiserMinimum(unsigned int quantiserMinimum)
 {
-	if (quantiserMinimum >= 10 && quantiserMinimum <= 51)
+	if (quantiserMinimum <= 51)
 		_param.rc.i_qp_min = quantiserMinimum;
 }
 
@@ -832,7 +864,7 @@ unsigned int x264Options::getQuantiserMaximum(void)
 
 void x264Options::setQuantiserMaximum(unsigned int quantiserMaximum)
 {
-	if (quantiserMaximum >= 10 && quantiserMaximum <= 51)
+	if (quantiserMaximum <= 51)
 		_param.rc.i_qp_max = quantiserMaximum;
 }
 
@@ -933,7 +965,7 @@ unsigned int x264Options::getAdaptiveQuantiserMode(void)
 
 void x264Options::setAdaptiveQuantiserMode(unsigned int adaptiveQuantiserMode)
 {
-	if (adaptiveQuantiserMode <= 1)
+	if (adaptiveQuantiserMode <= X264_AQ_AUTOVARIANCE)
 		_param.rc.i_aq_mode = adaptiveQuantiserMode;
 }
 
@@ -1386,9 +1418,15 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 		case X264_WEIGHTP_NONE:
 			strcpy((char*)xmlBuffer, "none");
 			break;
+#if X264_BUILD < 110
 		case X264_WEIGHTP_BLIND:
 			strcpy((char*)xmlBuffer, "blind");
 			break;
+#else
+		case X264_WEIGHTP_SIMPLE:
+			strcpy((char*)xmlBuffer, "simple");
+			break;
+#endif
 		case X264_WEIGHTP_SMART:
 			strcpy((char*)xmlBuffer, "smart");
 			break;
@@ -1461,6 +1499,7 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"fastPSkip", boolean2String(xmlBuffer, bufferSize, getFastPSkip()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"dctDecimate", boolean2String(xmlBuffer, bufferSize, getDctDecimate()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"psychoRdo", number2String(xmlBuffer, bufferSize, getPsychoRdo()));
+	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"psychoTrellis", number2String(xmlBuffer, bufferSize, getPsychoTrellis()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"noiseReduction", number2String(xmlBuffer, bufferSize, getNoiseReduction()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"interLumaDeadzone", number2String(xmlBuffer, bufferSize, getInterLumaDeadzone()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"intraLumaDeadzone", number2String(xmlBuffer, bufferSize, getIntraLumaDeadzone()));
@@ -1487,6 +1526,9 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 		case X264_AQ_VARIANCE:
 			strcpy((char*)xmlBuffer, "variance");
 			break;
+		case X264_AQ_AUTOVARIANCE:
+			strcpy((char*)xmlBuffer, "autoVariance");
+			break;
 	}
 
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"adaptiveQuantiserMode", xmlBuffer);
@@ -1895,8 +1937,13 @@ void x264Options::parseAnalyseOptions(xmlNode *node)
 			{
 				int weightedPredPFrames = X264_WEIGHTP_NONE;
 
+#if X264_BUILD < 110
 				if (strcmp(content, "blind") == 0)
 					weightedPredPFrames = X264_WEIGHTP_BLIND;
+#else
+				if (strcmp(content, "simple") == 0)
+					weightedPredPFrames = X264_WEIGHTP_SIMPLE;
+#endif
 				else if (strcmp(content, "smart") == 0)
 					weightedPredPFrames = X264_WEIGHTP_SMART;
 
@@ -1969,6 +2016,8 @@ void x264Options::parseAnalyseOptions(xmlNode *node)
 				setDctDecimate(string2Boolean(content));
 			else if (strcmp((char*)xmlChild->name, "psychoRdo") == 0)
 				setPsychoRdo(string2Float(content));
+			else if (strcmp((char*)xmlChild->name, "psychoTrellis") == 0)
+				setPsychoTrellis(string2Float(content));
 			else if (strcmp((char*)xmlChild->name, "noiseReduction") == 0)
 				setNoiseReduction(atoi(content));
 			else if (strcmp((char*)xmlChild->name, "interLumaDeadzone") == 0)
@@ -2019,6 +2068,8 @@ void x264Options::parseRateControlOptions(xmlNode *node)
 					adaptiveQuantiserMode = X264_AQ_NONE;
 				else if (strcmp(content, "variance") == 0)
 					adaptiveQuantiserMode = X264_AQ_VARIANCE;
+				else if (strcmp(content, "autoVariance") == 0)
+					adaptiveQuantiserMode = X264_AQ_AUTOVARIANCE;
 
 				setAdaptiveQuantiserMode(adaptiveQuantiserMode);
 			}
